function CRCS_demo()
%This script is a demo to show how to use C-RCS regression
%please cite the following paper when using this code

%References: Yuankai Huo, Katherine Aboud, Hakmook Kang, Laurie E. Cutting, Bennett A. Landman, 
% “Mapping Lifetime Brain Volumetry with Covariate-Adjusted Restricted Cubic Spline Regression from Cross-sectional Multi-site MRI”. 
% In International Conference on Medical Image Computing and Computer Assisted Intervention (MICCAI), Athens, Greece, October 2016 
%
%Code author: Yuankai Huo, 
% EECS Department
% Vandebrilt University, USA.
%
%E-mail: yuankai.huo@vanderbilt.com
% Date: June 2. 2016.
% Version: 1.0
% *************************************************************************

clc;clear;close all;
% *************************************************************************
% Set a experimental simulation 
% *************************************************************************
x = [0:0.01:2*pi]';%input x
linear_effect = (sin(x.*3)>0.8|sin(x.*3)<-0.6).*...
    [ones(floor(size(x,1)/2),1);-1.*ones(ceil(size(x,1)/2),1)]; %generate a linear effect
noise = rand(size(x))-0.5; %generate a random noise
y = 2*sin(x)+noise+linear_effect; %simulated observations
knots = prctile(x,linspace(0,100,6)); %knots


% *************************************************************************
% Use C-RCS
% *************************************************************************
X_covary = linear_effect; %covary out regressor
[bhat,bhat_covary]=crcs(x,y,knots,X_covary);
yhat_CRCS= fit_crcs(x,bhat,knots);


% *************************************************************************
% Show regression results
% *************************************************************************
figure('units','normalized','outerposition',[0 0 1 1]);
subplot(1,2,1);
hold on;
s1 = plot(x,2*sin(x),'r--','LineWidth',3);
s2 = plot(x,y,'b');
ylim([-6 6]);
h1 = legend([s1,s2],'hidden true','observed data with noise and linear effect','Location','SouthOutside');
set(h1,'FontSize',14);
title('simulated observation');

subplot(1,2,2);
hold on;
s3 = plot(x,2*sin(x),'r--','LineWidth',3);
s4 = plot(x,yhat_CRCS,'b');
ylim([-6 6]);
h2 = legend([s3,s4],'hidden true','C-RCS fitted result','Location','SouthOutside');
set(h2,'FontSize',14);
title('C-RCS regression');
end

