function [y_hat] = fit_crcs(x,bhat,knots)
%This the code to fit the results from crcs.m
%   please cite the following paper when using this code
%
%   References: Yuankai Huo, Katherine Aboud, Hakmook Kang, Laurie E. Cutting, Bennett A. Landman, 
%   “Mapping Lifetime Brain Volumetry with Covariate-Adjusted Restricted Cubic Spline Regression from Cross-sectional Multi-site MRI”. 
%   In International Conference on Medical Image Computing and Computer Assisted Intervention (MICCAI), Athens, Greece, October 2016 
%
%   INPUT ARGUMENTS:
%   x: A vector containing the covariate values x.
%   bhat: the estimated C-RCS coefficients of data.
%   knots: A vector of points at which the knots are to be placed.
%
%   OUTPUT ARGUMENTS:   
%   y_hat: C-RCS fitted result
%
%   Example
%   x = [0:0.01:2*pi]';%input x
%   linear_effect = (sin(x.*3)>0.8|sin(x.*3)<-0.6).*...
%     [ones(floor(size(x,1)/2),1);-1.*ones(ceil(size(x,1)/2),1)]; %generate a linear effect
%   noise = rand(size(x))-0.5; %generate a random noise
%   y = 2*sin(x)+noise+linear_effect; %simulated observations
%   knots = prctile(x,linspace(0,100,6)); %knots
%   X_covary = linear_effect; %covary out regressor
%   [bhat,bhat_covary]=crcs(x,y,knots,X_covary);
%   yhat_CRCS= fit_crcs(x,bhat,knots);

%Code author: Yuankai Huo, 
% EECS Department
% Vandebrilt University, USA.
%
%E-mail: yuankai.huo@vanderbilt.com
% Date: June 2. 2016.
% Version: 1.0


k = knots;

if size(x,1)>size(x,2)
    x = x'; %force to row vector
end    
    
if size(x,1)~=1
    error('X should be 1 by N matrix');
end

for i = 1:size(x,2)
    xi = x(1,i);
    y_hat(i,1) = bhat(1)+bhat(2).*xi+sum(bhat(3:end)'.*(xi-k(1:end)).^3.*(xi>k(1:end)));
end


end